@@ -26,6 +26,8 @@
 
 #include <QObject>
 
+class QWindow;
+
 class KACCOUNTS_EXPORT KAccountsUiPlugin : public QObject
 {
     Q_OBJECT
@@ -46,10 +48,12 @@ public:
      * Sets the selected Accounts-SSO provider to the plugin
      */
     virtual void setProviderName(const QString &providerName) = 0;
+
     /**
      * Called when the dialog for creating new account should show
      */
     virtual void showNewAccountDialog() = 0;
+
     /**
      * Called when an existing account should be configured
      * @param accountId The ID of the account that should be configured
@@ -63,6 +67,8 @@ public:
      */
     virtual QStringList supportedServicesForConfig() const = 0;
 
+    QWindow* transientParent() const;
+
 Q_SIGNALS:
     /**
      * Sometimes the plugins might take time to initialize the UI
@@ -71,6 +77,13 @@ Q_SIGNALS:
      * the dialog
      */
     void uiReady();
+
+    /**
+     * This should be emitted when the plugin finishes building the UI
+     * for configuring the selected account
+     */
+    void configUiReady();
+
     /**
      * Emitted when user successfully authenticated using this plugin
      * The params are the username & password that the user used to
